<?php die(); /* Do not remove this line */ ?>

# ====================================
# TREMENDUM TRANSCODER - CONFIGURATION
# ====================================
#
#

# ABOUT THIS FILE:
# ================
#
# The format for this file is very simple. A line starting with a "#" character
# is considered a comment and is ignored.
#
# Each setting has an indication for "Required" or "Optional".
# Required values must be filled in order to make the program work.
# Optional values can beleft blank or commented. The default value is indicated.
#
# Note that multiple instances of the same configuration setting overwrite the
# previous one. So the latest is the one taken into consideration.
#

# SECURITY NOTE
# =============
#
# Make sure that this configuration file is not writable by the web server user.


# PROGRAM AND FOLDER PATHS
# ========================
#

# Required.
# Full path to FFmpeg executable file.
ffmpeg_cmd = ..\bin\ffmpeg.exe

# Optional. Default: (empty)
# Full path to qt-faststart.
# This program is used to optimize the moov atoms of MP4 and MOV files so they
# are suitable for pseudo-streaming. It comes along with FFmpeg source.
faststart_cmd = ..\bin\qt-faststart.exe

# Optional. Default: (empty)
# Full path to flvtool2
# This program is used to optimize FLV files for pseudo-streaming.
flvtool2_cmd  = ..\bin\flvtool2.exe

# Required.
# Full path to the folder that will be used to write the flag files.
# This folder needs to be writable by the web user and the cron user.
flags_folder = ..\flags

# Required.
# Full path to the folder used for temporary file operations.
# Must be writable by the cron user.
temp_folder = ..\temp

# Required.
# Full path to the folder that contains the source media to be processed.
# Must be writable to the cron user when "source_completion_action" is set to
# "move" or "delete".
source_folder = ..\..\media\encode

# Required.
# Full path to the folder that is used to output the generated media files.
# Must be writable to the cron user.
# It can be the same as the source_folder.
target_folder = ..\..\media\done

# Optional. Default: 0
# Setting the nice_level allows to alter the scheduling priority of the commands
# executed by Tremendum Transcoder.
#
# This is useful if the machine running the program is a multipurpose machine,
# such as a web server, and we prefer to run the transcodings with a lower
# priority, so the resources of the web server are given priority.
#
# Choose from 0 to 20, 20 being the lowest priority.
# A value of 10 is recommended. A value of 0 does not alter priority.
# We translate this value in windows hosts to "start" command equivalent:
# 1-10 = /BELOWNORMAL, 11-20 /LOW.
nice_level = 10

# Optional. Default: (empty)
# Note: Do not add params to this command.
# For windows hosts use: start
# For linux/unix hosts use: nice, preferably with full path (i.e. /usr/bin/nice)
# Note that this setting is optional, and you can also control the execution
# priority of tt-cron.php in your crontab like any other shell command.
nice_cmd = start

# Optional. Default: (empty)
# Used in portable mode to automatically call the backend without the need for
# any cron setup. Still, tt-cron.bat needs to be adjusted accordingly.
pseudo_cron_enabled = true


# INPUT AND OUTPUT PROCESSING
# ===========================
#
# The following settings control the way Tremendum Transcoder processes your
# media files. With the default values, media files are loaded from "encode"
# folder, and transcoded versions are generated in equivalent paths under
# the "done" folder, in a subfolder made of the source filename with the
# extension attached to the name.
#
# This default setup provides an easy, organized and overwrite-safe way of
# transcoding media files.
#
# Tremendum Transcoder is very flexible and can be configured in multiple ways
# to achieve our desired results.
#
# Below are the settings that control its behaviour.

# Optional. Default: false
# When set to true, media files in subfolders of the source_folder are also
# processed.
recursive_mode = true

# Optional. Default: true
# When creating the target files, put them inside a folder named after the
# source file being processed. For example, from source file "encode/video.avi",
# we would create a target mp4 file like "done/video/video.mp4".
output_subfolder_create = true

# Optional. Default: true
# When creating the target folder, also include the source file extension in the
# folder name.
#
# This prevents the scenario when two different source files have the same name
# but different extension, such as "video.avi" and "video.mov", being those two
# different videos. For example, from source file "encode/video.avi", we would
# create a target mp4 file like "done/video_avi/video.mp4".
#
# Another way to avoid filename collisions is to use "%sourceext%" in the
# filename templates. (See filename templates section)
output_subfolder_add_extension = true

# Optional. Default: false
# When this is set to true, the target files are created in the root of the
# target folder regardless of the location inside the source_folder.
#
# This can be useful in certain conditions in combination with an adequate
# filename template, but it is easier to run into filename collisions.
#
# A filename collision is when a target file to be created already exists.
# We can configure Tremendum Transcoder to skip or overwrite existing files.
# In certain scenarios, collisions are useful.
output_to_root = false

# Optional. Default: (empty)
# This allows to specify the target file permissions. When empty, the program
# will use the default file permissions of your php install.
#
# Use 4 digit octal notation.
# For example, a world writable file would be: 0666
target_file_mode =

# Optional. Default: (empty)
# This allows to specify the target folder permissions. When empty, the program
# will use the default folder permissions of your php install.
#
# Use 4 digit octal notation.
# For example, a world writable folder would be: 0777
target_folder_mode =

# Options. Default: false
# When set to true, existing files in the target_folder are overwritten if
# there's a filename collision.
#
# The default behaviour is to skip already present files.
overwrite_files = false

# Optional. Default (empty)
# Defines what action to take with the source file (if any), after all the
# selected profiles have been processed.
#
# Possible values are: copy, move and delete.
# Set to empty to do nothing.
source_completion_action =



# QUEUE SORTING OPTIONS
# =====================
#
# The following configuration options allow altering the order in which source
# files are processed.
#
# This is useful when you want to give priority to certain files, or to achieve
# more complex tasks. Please note that if you don't require sorting for any
# specific reason, it is better not to use any sorting at all for performance
# reasons, specially if you want to process huge amounts of source files.
#
# Leave empty the fields or comment the line for no sorting (faster)
#
# Explanation of the sorting fields:
#
#   name: Filename to be processed. ie. "video.avi"
#   ext:  Extension of the file. ie. "avi"
#   size: Filesize of the file to process.
#   date: Last modification date of the file.
#
# Sort order modifiers:
#   ASC:  Ascending order. i.e. a-z, 0-9
#   DESC: Descending order. i.e. z-a, 9-0
#

# Optional. Default: (empty)
# Local sorting only sorts files and folders at the current folder level.
# This means that just the files and folders present in the currently scanned
# folder are sorted.
#
# Allowed values: name, size, date, ext
# Default sorting is ASC. You can set explicit ASC or DESC.
# Multiple sort fields are allowed separated by a comma, ie. size DESC, name
#
queue_sort_local_files =

# Optional. Default: (empty)
# Local sorting of folders can be done by name or date (last modified date).
#
# Allowed values: name, date
#
queue_sort_local_folders =

# Optional. Default: (empty)
# The global sorting performs the sort after all files to be processed have been
# collected.
#
# Note the difference in sorting, for example sorting by "size DESC", will give
# us the biggest files of any folders at the beginning of the queue, while local
# sorting "size DESC" will give us the biggest file of the current folder first,
# then the 2nd largest file in that same folder regardless if there are bigger
# files in different folders.
#
# If set, this overrides any local sorting setting.
#
# Allowed values: name, size, date, ext
#
queue_sort_global =



# MEDIA INPUT FILTERING
# =====================
#
# The following settings allow us to filter what media files are to be
# processed by Tremendum Transcoder.
#

# Optional. Default: (empty)
# Limit the media files that we want to process from the source_folder to the
# ones that have a file extension of the command separated list provided. If no
# extensions are specified, all files are considered for processing regardless
# of their extensions.
#
# Extensions are case insensitive.
file_extensions = mov, mp4, mpg, mpeg, avi, wmv, m2t, m2ts, webm, ogg, flv

# Optional. Default: (empty)
# Advanced filtering of input files to process using Perl Compatible Regular
# Expressions.
#
# Note that the match is performed against the full path of the file, not just
# the filename.
#
# Set the regular expression without delimiters or modifiers. All matches are
# case sensitive.
#
# Examples:
#
# Process files that are like: episode1.wmv, episode3.AVI etc.
# /episode[1-5]\.(wmv|WMV|mpg|MPG|avi|AVI)$
#
# Process files that are under a subfolder called "web". ie. foo/web/video.mp4
# /web/.+\.(mp4|MP4)$
#
# For a detailed explanation or Perl Compatible Regular Expressions visit:
# http://www.php.net/manual/en/reference.pcre.pattern.syntax.php
#
# You can test your regular expressions with a program like The Regex Coach:
# http://weitz.de/regex-coach/
#
file_input_regex =

# Optional. Default: (empty)
# Advanced filtering of input files to exclude using Perl Compatible Regular
# Expressions.
#
# Note that the match is performed against the full path of the file, not just
# the filename.
#
# Set the regular expression without delimiters or modifiers. All matches are
# case sensitive.
#
# This test is performed after file_input_regex, and provides a powerful method
# to exclude files using regular expressions.
#
# Example:
#
# Exclude any files that contain "/bad/" in their path: /videos/bad/episode1.wmv
# /bad/
#
#
skip_file_regex =



# DEFAULT FILENAME TEMPLATES
# ==========================
#
# Tremendum Transcoder allows very flexible filename templates. These define how
# the resulting filename from processing a profile will be.
#
# The filename template can optionally include variables that are replaced at
# run time with their calculated value.
#
# Variable names:
#   %sourcename%       Contains the source filename without extension.
#                      ie. "video" from "video.mpg"
#   %sourceext%        Contains the source extension only. ie. "mpg" from
#                      "video.mpg"
#   %format%           Contains the profile identifier. ie. "webm_360" for the
#                      default WebM 360p video profile.
#   %ext%              This variable is mandatory, and contains the extension of
#                      the target filename as defined in the profile.
#   %width%            Contains the width as specified in the profile width
#                      setting.
#   %height%           Contains the height as specified in the profile height
#                      setting.
#   %outputwidth%      Contains the computed output width. The value is affected
#                      depending on the resize mode (crop, proportional, etc).
#   %outputheight%     Contains the computed output height. The value is
#                      affected depending on the resize mode.
#   %sourcewidth%      Contains the width from the source file.
#   %sourceheight%     Contains the height from the source file.
#
# Filename templates also allow regular expressions to match against the source
# video filename and allows us to use the captures from the matches in the
# filename template. To make use of these variables, you need to set a
# "filename_regex" or "default_filename_regex" accordingly.
#
# Please check the section that describes filename_regex for more info.
#
# Variable names:
#   %rx1%              Contains the value of the first capture.
#   %rx2%              Contains the value of the second capture.
#   %rxN%              Contains the value of "N" (where N is a number) capture.
#
#   Variables that do not correspond to any capture are just removed from the
#   filename template.
#
#   We also have a powerful feature that allows us to deal with the situation
#   when no matches occur. In that case we can default the values of those non
#   matched variables to a predefined static value, or one of the previous
#   variable names. Pay attention to the special format and separator characters
#   and notice how they differ: "% # %" and "% = %".
#
# Variable name:
#   %rxN#VARIABLE%     This means replace with the capture "N" (where N is a
#                      number), and if we don't match that capture, then use the
#                      "VARIABLE" value instead. ie: %rx1#sourcename%
#
# Variable name:
#   %rxN=something%    This means replace with the capture "N" (where N is a
#                      number), and if we don't match that capture, then use the
#                      literal text "something" instead. Notice the difference
#                      with the previous format, as the separator used is "=".
#                      ie. %rx1=some_text%
#
#
# FILENAME REGEX:
#
# The filename regex define the regular expression that is used to match against
# the source filename without extension (just the filename without the full path
# and without extension). These regular expressions are used to capture parts of
# text from the source filename and use it in the filename templates, allowing
# us to achieve very complex file naming schemes.
#
# For example, let's assume we want to create filenames that comply with the
# naming convention for a CMS that uses:
# video_title-format_short-number.ext
#
# To make sure we preserve the naming convention from source files that are
# already in this CMS friendly format, and at the same time make sure we create
# a complying name from those source files that do not follow the convention, we
# would use the following combination:
#
#   default_filename_regex = (.+)?-(.+)?-(\d+)$
#   default_filename_template = %rx1#sourcename%-%format%-%rx3=1%.%ext%
#
#   To better illustrate the way this works, we will use 2 example source files:
#      encode/funny_monkey-movhd-3.mov
#      encode/surf_contest.mov
#
#   When processing those files without settings and a profile called for
#   example "mobile", the resulting filenames will be these:
#      done/funny_monkey-mobile-3.mp4
#      done/surf_contest-mobile-1.mp4
#
#

# Optional. Default: %sourcename%-%format%.%ext%
# Sets the default filename template to use for profiles that do not define a
# specific one.
#
default_filename_template = %sourcename%-%format%.%ext%

# Optional. Default: (empty)
# Sets the Perl Compatible Regular Expression to capture groups of text to use
# in filename templates.
#
default_filename_regex =

# Optional. Default: %sourcename%.%ext%
# Use the following filename template when copying / moving source media file to
# set a new filename.
#
# Note that only the following variables are available:
# %sourcename%, %ext%, %sourcewidth%, %sourceheight%,
# %rxN%, %rxN#VARIABLE%, $rxN=something%
#
source_filename_template = %sourcename%.%ext%

# Optional. Default: (empty)
# Defines the regex to use in combination with source_filename_template.
source_filename_regex =



# DEFAULT PROFILE VALUES
# ======================
#

# Optional. Default: squeeze
# Sets the default resize mode for profiles that do not have an explicit resize
# mode set. There are 4 modes available:
#
#      squeeze: Set the output dimensions to be exactly the desired width and
#               height, stretching the image to fit the dimensions.
#
#         crop: The image has the desired width and height preserving the aspect
#               ratio and discarding pixels as needed.
#
# proportional: Sets the output size proportional to the given width or height.
#               If both values are given, only width is considered.
#
#      maxside: Sets the output size so that no size is larger than the
#               specified maxside. The maxside value is taken from the width
#               setting.
#
default_resize_mode = squeeze

# Optional. Default: false
# When set, resize operations make sure that the target pixel dimensions are
# even (divisible by 2).
#
# This is useful when dealing with profiles that use codecs that do not support
# odd image dimensions.
#
# This value can be changed in per profile basis.
default_force_divisible = false

# Optional.
# Set the full path to the default font file to use for text overlays.
# If you want to use text overlays you need to set this value, or per profile
# value.
#
# This value can be changed in per profile basis.
default_text_font = ../../media/fonts/Droid-Serif/DroidSerif-Regular.ttf



#
# MISCELLANEOUS SETTINGS
# ======================
#

# Optional. Default: false
# When set to true, only the relative filenames to the source_folder and
# target_folder are shown in the logs.
#
# This is useful if the path to those folders is large, so the logs are more
# readable.
#
# ie. Normal mode: /path/to/media/encode/episode1/video.mpg
#      Short mode: episode1/video.mpg
short_path_in_logs = false

# Optional. Default: false
# When set to true, the program will collect certain stats about the source
# media files it processed and append them to the compression log.
collect_stats = false

# Optional. Default: false
# When set to true, the program will collect execution time stats about the
# profiles it processed.
collect_stats_time = false

# Optional. Default: false
# When set to true, the batch summary log will include details of each
# file that has been Done and Skipped. Errors are always included.
collect_stats_detailed = false

# Optional. Default: false
# When set to true, the program will send an email report containing the
# compression log.
send_report = false

# Optional. Default: (empty)
# Use this subject in the email report.
email_subject = Tremendum Transcoder batch completed.

# Optional. Default: (empty)
# Use this email address to send the email report to.
#email_to_address = user@example.com

# Optional. Default: false
# When set to true, no filesystem changes are performed. This is very useful to
# test the different configurations and filename templates without altering any
# files or waiting for media files to be processed.
simulation_mode = false

# Optional. Default: error
# Specify the log level detail from FFmpeg in the compression log.
# When customizing your profiles it is useful to change this to "warning" in
# order to optimize the parameters to suit your installed FFmpeg version. Same
# when upgrading the installed versions, as FFmpeg tends to introduce various
# parameter syntax changes between versions. The "progress" option enables a
# graphical progress bar in the web interface.
#
# Allowed values: progress, warning, error.
ffmpeg_loglevel = progress

# Optional. Default: 0
# Set an encoding time limit. This is useful during profile customization to
# test the resulting encodings without having to compress the total length of
# the source media.
#
# Choose: 1 to 59 seconds.
# Value of 0 or empty, equals to no limit.
debug_enc_limit = 0

# Optional. Default: 0
# Checks the free space in the filesystem of target_folder.
#
# If the free space is smaller than the amount specified here, stop processing
# and show a warning message in the log. Values are specified in megabytes.
#
# 0 = No checking of free space. 
# 1024 = 1 gigabyte
min_space_target = 0

# Optional. Default: 0
# Checks the free space in the filesystem of temp_folder.
#
# If the free space is smaller than the amount specified here, stop processing
# and show a warning message in the log. Values are specified in megabytes.
#
# 0 = No checking of free space. 
# 1024 = 1 gigabyte
min_space_temp = 0


# COMPATIBILITY SETTINGS
# ======================
#
# The following settings allow to run Tremendum Transcoder with older versions
# of FFmpeg. It is recommended to use recent versions of FFmpeg, which provide
# enhanced features and support for input and output formats. However if you are
# not able to use a newer version, you are still able to use Tremendum
# Transcoder with an older FFmpeg version.
#
# Older versions may not support all the functionality, and some of the default
# profiles may not work due to lack of supported codecs or features.
# We strongly recommend an up to date FFmpeg whenever possible.
#
# The diagnostics file provided with the program (tt-diag.php) will show the
# suggested compatibility settings based on your version of FFmpeg, but only if
# they are needed.
#
#compat_loglevel    = false
#compat_verbose     = false
#compat_crop        = false
#compat_crop_old    = false
#compat_drawtext    = false
#compat_scale       = false
#compat_deinterlace = false


# END of settings :)
#
# Copyright (c) 2013 Tremendum Transcoder. All rights reserved.
#